Crate codex_rmcp_client

Crate codex_rmcp_client 

Structs

ElicitationResponse
ExecutorStdioServerLauncher
Starts MCP stdio servers through the executor process API.
ListToolsWithConnectorIdResult
LocalStdioServerLauncher
Starts MCP stdio servers as local child processes.
OAuthProviderError
OauthLoginHandle
RmcpClient
MCP client implemented on top of the official rmcp SDK. https://github.com/modelcontextprotocol/rust-sdk
StoredOAuthTokens
StreamableHttpOAuthDiscovery
ToolWithConnectorId
WrappedOAuthTokenResponse
Wrap OAuthTokenResponse to allow for partial equality comparison.

Enums

Elicitation
ElicitationAction
Represents the possible actions a user can take in response to an elicitation request.
McpAuthState
McpAuthStatus
McpLoginRequirement

Traits

InProcessTransportFactory
Recreates a fresh in-process MCP byte stream whenever the client needs one.
StdioServerLauncher
Launches an MCP stdio server and returns the transport for rmcp.

Functions

delete_oauth_tokens
determine_streamable_http_auth_status
Determine the authentication status for a streamable HTTP MCP server.
determine_streamable_http_auth_status_from_credentials
Determine authentication status using only configured and stored credentials.
determine_streamable_http_auth_status_with_http_client
Determine authentication status while routing OAuth discovery through the provided HTTP client.
discover_streamable_http_oauth
discover_streamable_http_oauth_with_http_client
is_authentication_required_error
Returns whether an RMCP client error indicates that authentication is required.
perform_oauth_login
perform_oauth_login_return_url
perform_oauth_login_return_url_with_http_client
perform_oauth_login_silent
save_oauth_tokens
supports_oauth_login
Attempt to determine whether a streamable HTTP MCP server advertises OAuth login.

Type Aliases

SendElicitation
Interface for sending elicitation requests to the UI and awaiting a response.