Structs
- Elicitation
Response - Executor
Stdio Server Launcher - Starts MCP stdio servers through the executor process API.
- List
Tools With Connector IdResult - Local
Stdio Server Launcher - Starts MCP stdio servers as local child processes.
- OAuth
Provider Error - Oauth
Login Handle - Rmcp
Client - MCP client implemented on top of the official
rmcpSDK. https://github.com/modelcontextprotocol/rust-sdk - StoredO
Auth Tokens - Streamable
HttpO Auth Discovery - Tool
With Connector Id - WrappedO
Auth Token Response - Wrap OAuthTokenResponse to allow for partial equality comparison.
Enums
- Elicitation
- Elicitation
Action - Represents the possible actions a user can take in response to an elicitation request.
- McpAuth
State - McpAuth
Status - McpLogin
Requirement
Traits
- InProcess
Transport Factory - Recreates a fresh in-process MCP byte stream whenever the client needs one.
- Stdio
Server Launcher - Launches an MCP stdio server and returns the transport for rmcp.
Functions
- delete_
oauth_ tokens - determine_
streamable_ http_ auth_ status - Determine the authentication status for a streamable HTTP MCP server.
- determine_
streamable_ http_ auth_ status_ from_ credentials - Determine authentication status using only configured and stored credentials.
- determine_
streamable_ http_ auth_ status_ with_ http_ client - Determine authentication status while routing OAuth discovery through the provided HTTP client.
- discover_
streamable_ http_ oauth - discover_
streamable_ http_ oauth_ with_ http_ client - is_
authentication_ required_ error - Returns whether an RMCP client error indicates that authentication is required.
- perform_
oauth_ login - perform_
oauth_ login_ return_ url - perform_
oauth_ login_ return_ url_ with_ http_ client - perform_
oauth_ login_ silent - save_
oauth_ tokens - supports_
oauth_ login - Attempt to determine whether a streamable HTTP MCP server advertises OAuth login.
Type Aliases
- Send
Elicitation - Interface for sending elicitation requests to the UI and awaiting a response.